
//*********************************************************************
//*********************************************************************
//*********************************************************************
// 		Axiohm.h
//
//		Include file for Special Axiohm-enhanced features
//
//*********************************************************************
//
//  Revisions:
//  97OCT17 Addition of MICR exception DirectIO command				MLT
//	98MAR31 Additions of A756-8xxx Flash/Remote diag cmds			STW
//	98APR06 Modification to commands remove A756 -> AXIOHM			STW
//	98APR29 Remove unused command defines							STW
//	98MAY07 Add ResultCodeExtended Defines							STW
//	98MAY18 Add Addition ResultCodeExtended Defines					STW
//  98JUN18 Add Katakana character set definition					STW
//  98JUN30 Add Command to control concurrent slp/jrn printing		MLT
//	98JUL23 Add ResultCodeExtended Defs for NO_SERVICE on open		STW
//  98NOV12 Add new Remote Diag commands A794/58					STW
//  98NOV19 Add new command for Downloaded bit image density		STW
//			Changed the values of SLIP/JRN concurrent & stop
//			print on paper low to be 0x50xx based.
//  98DEC02 Add command to change value of m_Coded128CheckIncl		STW
//  98DEC10 Add command to flip check								STW
//	99JAN25 Add command to change Bitmap store location				STW
//	99JAN27 Add Error Result Codes for Flash/RAM loads				STW
//	99FEB05 Add DirectIO commands for new remote diagnostics		STW
//
//*********************************************************************

#ifndef AXIOHM_H
#define AXIOHM_H

//*********************************************************************
//	Axiohm Specific Numbers
//*********************************************************************

#define AXIOHM_KATAKANA 199			// Katakana Character set A714
#define AXIOHM_KANJI	198			// Kanji Character Set A756-8xxx

//*********************************************************************
//	Axiohm DirectIO Command Numbers
//*********************************************************************

#define AXIOHM_MICR_EXCEPTION			1000	// Axiohm MICR Exception Command

#define AX_SLIP_JRN_CONCURRENT			0x50A0	// Command to turn on and off concurrent slip and jrnl printing
#define AX_STOP_PRINT_ON_PAPER_LOW		0x50A1	// Command to set/unset StopPrintOnPaperLow

#define AX_DOWNLOADED_BITIMAGE_DENSITY	0x50A2	// Command to change the value of m_DownloadedBitImageDensity
#define CODE128_CHECK_INCLUDED			0x50A3	// Command to change the value of m_Code128CheckIncl

#define AXIOHM_EXECUTE_CHECK_FLIP		0x50A4	// Command to Flip the document in the slip station
#define AX_DOWNLOAD_BITIMAGE_TO_FLASH	0x50A5	// command to change choice of Download location for bitmaps

//*********************************************************************
//	A756-8xxx Flash Defines for Use in DirectIO
//*********************************************************************

#define AX_ERASE_CHARLOGO_FLASH		4049	// Erase Character Set/Logo Flash area
#define AX_ERASE_USERDATA_FLASH		4050	// Erase User Data Flash Area

#define AX_LOAD_CHARS_TO_RAM		2250	// Load Character Set into RAM
#define AX_LOAD_CHARS_TO_FLASH		2251	// load Character Set into Flash

#define AX_WRITE_TO_USERDATA		2739	// Write to User Data Flash Area
#define AX_READ_FROM_USERDATA		2752	// Read from User Data Flash Area

#define TRANSMIT_FLASH_STATUS		2775	// Transmit the flash status

//*********************************************************************
//	Axiohm DirectIO Command Defines for Remote Diagnostics
//*********************************************************************

#define	AXIOHM_REMOTE_DIAGNOSTICS			4940	// Command to Request Remote Diagnostics

//*********************************************************************
//	Defines for DirectIO parameter pData -> Remote Diagnostic 
//  commands defined - GS I @ n.  This define in pData will send the defined command

#define SERIALNO_WRITETO_NVRAM				0x4020	// GS I @ <SP> - Serial #, Write to NVRAM
#define SERIALNO_TONVRAM_RCPTVER			0x4021	// GS I @ !    - Serial #, Write to NVRAM, print on rcpt to verify
#define SERIALNO_RETURN						0x4023	// GS I @ #    - Return Serial #

#define CLASS_MODELNO_WRITETO_NVRAM			0x4024	// GS I @ $    - Class/Model #, Write to NVRAM
#define CLASS_MODELNO_TONVRAM_RCPTVER		0x4025	// GS I @ %    - Class/Model #, Write to NVRAM, print on rcpt to verify
#define	CLASS_MODELNO_RETURN				0x4027	// GS I @ '    - Return Class/Model #

#define	BOOT_FIRMWARE_PARTNO_RETURN			0x402B	// GS I @ +    - Return Boot Firmware Part #
#define	BOOT_FIRMWARE_CRC_RETURN			0x402F	// GS I @ /    - Return Boot Firmware CRC

#define	FLASH_FIRMWARE_PARTNO_RETURN		0x4033	// GS I @ 3    - Return Flash Firmware Part #
#define	FLASH_FIRMWARE_CRC_RETURN			0x4037	// GS I @ 7    - Return Flash Firmware CRC

#define	RECLINES_TALLY_WRITETO_NVRAM		0x4080	// GS I @ 80H  - Set RecLines Tally, Write to NVRAM
#define	RECLINES_TALLY_TONVRAM_RCPTVER		0x4081	// GS I @ 81H  - Set RecLines Tally, print to rcpt to verify
#define	RECLINES_TALLY_CLEAR				0x4082	// GS I @ 82H  - Clear RecLines Tally, set to 0
#define	RECLINES_TALLY_RETURN				0x4083	// GS I @ 83H  - Return RecLines Tally

#define	KNIFECUT_TALLY_WRITETO_NVRAM		0x4084	// GS I @ 84H  - Set Knifecut Tally, Write to NVRAM
#define	KNIFECUT_TALLY_TONVRAM_RCPTVER		0x4085	// GS I @ 85H  - Set Knifecut Tally, print to rcpt to verify
#define	KNIFECUT_TALLY_CLEAR				0x4086	// GS I @ 86H  - Clear Knifecut Tally, set to 0
#define	KNIFECUT_TALLY_RETURN				0x4087	// GS I @ 87H  - Return Knifecut Tally

#define	SLIPCHAR_TALLY_WRITETO_NVRAM		0x4088	// GS I @ 88H  - Set Slipchar Tally, Write to NVRAM
#define	SLIPCHAR_TALLY_TONVRAM_RCPTVER		0x4089	// GS I @ 89H  - Set Slipchar Tally, print to rcpt to verify
#define	SLIPCHAR_TALLY_CLEAR				0x408A	// GS I @ 8AH  - Clear Slipchar Tally, set to 0
#define	SLIPCHAR_TALLY_RETURN				0x408B	// GS I @ 8BH  - Return Slipchar Tally

#define	MICRREAD_TALLY_WRITETO_NVRAM		0x408C	// GS I @ 8CH  - Set MicrRead Tally, Write to NVRAM
#define	MICRREAD_TALLY_TONVRAM_RCPTVER		0x408D	// GS I @ 8DH  - Set MicrRead Tally, print to rcpt to verify
#define	MICRREAD_TALLY_CLEAR				0x408E	// GS I @ 8EH  - Clear MicrRead Tally, set to 0
#define	MICRREAD_TALLY_RETURN				0x408F	// GS I @ 8FH  - Return MicrRead Tally

#define	HOURS_ON_TALLY_WRITETO_NVRAM		0x4090	// GS I @ 90H  - Set Hours on Tally, Write to NVRAM
#define	HOURS_ON_TALLY_TONVRAM_RCPTVER		0x4091	// GS I @ 91H  - Set Hours on Tally, print to rcpt to verify
#define	HOURS_ON_TALLY_CLEAR				0x4092	// GS I @ 92H  - Clear Hours on Tally, set to 0
#define	HOURS_ON_TALLY_RETURN				0x4093	// GS I @ 93H  - Return Hours on Tally

#define BOOT_FIRMWARE_VERSION_RETURN		0x4097	// GS I @ 97H  - Return Boot Firmware Version number
	
#define FLASH_FIRMWARE_VERSION_RETURN		0x40A3	// GS I @ A3H  - Return Flash Firmware Version number
	
#define FLASHCYCLES_TALLY_WRITETO_NVRAM		0x40A4  // GS I @ A4H  - Set FlashCycles Tally, Write to NVRAM
#define FLASHCYCLES_TALLY_TONVRAM_RCPTVER	0x40A5  // GS I @ A5H  - Set FlashCycles Tally, print to rcpt to verify
#define FLASHCYCLES_TALLY_CLEAR				0x40A6  // GS I @ A6H  - Clear FlashCycles Tally, set to 0
#define FLASHCYCLES_TALLY_RETURN			0x40A7  // GS I @ A7H  - Return FlashCycles Tally

#define KNIFEJAMS_TALLY_WRITETO_NVRAM		0x40A8  // GS I @ A8H  - Set KnifeJams Tally, Write to NVRAM
#define KNIFEJAMS_TALLY_TONVRAM_RCPTVER		0x40A9  // GS I @ A9H  - Set KnifeJams Tally, print to rcpt to verify
#define KNIFEJAMS_TALLY_CLEAR				0x40AA  // GS I @ AAH  - Clear KnifeJams Tally, set to 0
#define KNIFEJAMS_TALLY_RETURN				0x40AB  // GS I @ ABH  - Return KnifeJams Tally

#define COVEROPENINGS_TALLY_WRITETO_NVRAM	0x40AC  // GS I @ ACH  - Set CoverOpenings Tally, Write to NVRAM
#define COVEROPENINGS_TALLY_TONVRAM_RCPTVER	0x40AD  // GS I @ ADH  - Set CoverOpenings Tally, print to rcpt to verify
#define COVEROPENINGS_TALLY_CLEAR			0x40AE  // GS I @ AEH  - Clear CoverOpenings Tally, set to 0
#define COVEROPENINGS_TALLY_RETURN			0x40AF  // GS I @ AFH  - Return CoverOpenings Tally

#define MAX_TEMPERATURE_TALLY_RETURN		0x40B3	// GS I @ B3H  - Return MaxTemperature Tally

#define SLIP_LINES_TALLY_WRITETO_NVRAM		0x40B4	// GS I @ B4H  - Set SlipLinesTally, Write to NVRAM
#define SLIP_LINES_TALLY_TONVRAM_RCPTVER	0x40B5  // GS I @ B5H  - Set SlipLinesTally, Print to rcpt to verify
#define SLIP_LINES_TALLY_CLEAR				0x40B6  // GS I @ B6H  - Clear SlipLinesTally, set to 0
#define SLIP_LINES_TALLY_RETURN				0x40B7	// GS I @ B7H  - Return SlipLines Tally

//*********************************************************************
//	Axiohm Specific Returns for ResultCodeExtended in ErrorEvents
//*********************************************************************

#define	AXIOHM_BADREAD_DATA		1		// MICR Bad Read of Check
#define	AXIOHM_NOCHECK_NODATA	2		// MICR No Check or No Data from check
#define	AXIOHM_PAPERJAM_NODATA	3		// MICR Paper Jam No Data from Check
#define	AXIOHM_NOCHARS_NODATA	4		// MICR No MICR Characters or Data from check
#define AXIOHM_KNIFE_SLIP_JAM	5		// Printer Knife or Slip jam
#define	AXIOHM_SLIP_MOTOR_JAM	6		// Printer Slip head motor jam
#define AXIOHM_KNIFE_ERROR		7		// Printer Knife error
#define AXIOHM_FATAL_ERROR		49		// Printer/MICR fatal error in device
#define	AXIOHM_UNKNOWN_ERROR	50		// who knows?

//*********************************************************************
//	Axiohm Specific Returns for ResultCodeExtended in OPEN()
//*********************************************************************

#define AXIOHM_REGQUERY_COM_ERROR	0x1000		// Error querying registry for a specific com setting
#define AXIOHM_REG_QUERY_ERROR		0x1001		// Error querying registry for a necessary value other than com
#define AXIOHM_INVALID_PORT			0x1002		// Com port specified is not a legal value
#define AXIOHM_INVALID_BAUDRATE		0x1003		// Baudrate specified is not supported
#define AXIOHM_INVALID_PARITY		0x1004		// Parity specified is not supported
#define AXIOHM_INVALID_PROTOCOL		0x1005		// Communications protocol is not supported or is invalid
#define AXIOHM_RECEIVEBUFF_ERROR	0x1006		// Receive buffer is too small or non-existent

//*********************************************************************
//	Axiohm Specific Returns for ResultCodeExtended When Using Flash
//*********************************************************************

#define AXIOHM_FLASH_LOGOAREA_FULL	0x2000		// Logo failed because Flash area is full
#define AXIOHM_FLASH_CHARAREA_FULL	0x2001		// Character load failed because Flash area is full
#define AXIOHM_RAM_LOGOAREA_FULL	0x2002		// Logo load failed because RAM area is full


//*********************************************************************
//	End of Axiohm.h

#endif
